@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # $File: //member/autrijus/PAR/script/par.pl $ $Author: autrijus $
-# $Revision: #57 $ $Change: 5898 $ $DateTime: 2003/05/16 16:30:10 $ vim: expandtab shiftwidth=4
+# $Revision: #65 $ $Change: 6460 $ $DateTime: 2003/06/11 17:57:47 $ vim: expandtab shiftwidth=4
 
 package __par_pl;
 
@@ -132,6 +132,7 @@ followed by a 8-bytes magic string: "C<\012PAR.pm\012>".
 
 =cut
 
+$ENV{PAR_CLEARTEMP} = 1 unless exists $ENV{PAR_CLEARTEMP};
 my $quiet = !$ENV{PAR_DEBUG};
 
 # fix $0 if invoked from PATH
@@ -145,7 +146,7 @@ if (-s "$0$Config{_exe}") {
     $0 = "$0$Config{_exe}";
 }
 elsif (!-s $0) {
-    foreach my $dir (split /$Config{path_sep}/, $ENV{PATH}) {
+    foreach my $dir (split /\Q$Config{path_sep}\E/, $ENV{PATH}) {
         $dir =~ s/\Q$Config{_delim}\E$//;
         (($0 = "$dir$Config{_delim}$0$Config{_exe}"), last)
             if -s "$dir$Config{_delim}$0$Config{_exe}";
@@ -204,6 +205,7 @@ my ($start_pos, $data_pos);
         elsif ( $fullname =~ m|^/?shlib/| and defined $ENV{PAR_TEMP} ) {
             # should be moved to _tempfile()
             $filename = "$ENV{PAR_TEMP}/$basename$ext";
+            print "SHLIB: $filename\n";
             open $out, '>', $filename or die $!;
             binmode($out);
             print $out $buf;
@@ -228,7 +230,7 @@ my ($start_pos, $data_pos);
                 next unless /\Q$module\E$/;
                 $key = $_; last;
             }
-            delete $require_list{$key};
+            delete $require_list{$key} if defined($key);
         } or return;
 
         $INC{$module} = "/loader/$filename/$module";
@@ -318,6 +320,8 @@ if (!$start_pos or ($ARGV[0] eq '--par-options' && shift)) {
     }
 }
 
+# XXX -- add --par-debug support!
+
 # }}}
 
 # Output mode (-O) handling {{{
@@ -490,8 +494,7 @@ if ($out) {
             my $extract_name = $1;
             my $dest_name = File::Spec->catfile($ENV{PAR_TEMP}, $extract_name);
             $member->extractToFileNamed($dest_name);
-            outs(qq(Extracting "$member_name" to "$dest_name", and loading the file));
-            my $libref = DynaLoader::dl_load_file($dest_name, 0x0); # $module->dl_load_flags);
+            outs(qq(Extracting "$member_name" to "$dest_name"));
         }
     }
     # }}}
@@ -536,7 +539,7 @@ sub require_modules {
 my $tmpdir;
 sub tmpdir {
     return $tmpdir if defined $tmpdir;
-    my @dirlist = (@ENV{qw(PAR_TMP_DIR TMPDIR TEMP TMP)}, qw(C:/temp /tmp /));
+    my @dirlist = (@ENV{qw(PAR_TEMP PAR_TMP_DIR TMPDIR TEMP TMP)}, qw(C:/temp /tmp /));
     {
         if (${"\cTAINT"}) { eval {
             require Scalar::Util;
@@ -610,6 +613,7 @@ sub pod_strip {
     }gsex;
     $pl_text = '#line 1 "' . ($filename) . "\"\n" . $pl_text
         if length $filename;
+    $pl_text =~ s/^#line 1 (.*\n)(#!.*\n)/$2#line 2 $1/g;
 
     return $pl_text;
 }
